﻿(function () {
    var module = appStatisticsPlugin.getAngularModule();
    module.controller('app.statistics.jobDetailsCtrl',
        ['$scope', '$interval', '$stateParams', 'app.statistics.jobService', 'app.statistics.taskService', '$modal',
        function ($scope, $interval, $stateParams, jobService, taskService, $modal) {
            $scope.interval = defaultPageUpdateInterval;
            $scope.curTaskPage = 1;
            $scope.taskPageSize = 12;

            var getJobDetails = function () {
                jobService.getJobDetails({ id: $stateParams.id }, function (job) {
                    $scope.job = job;
                    $scope.job.DateCreated = CSharpDateToString($scope.job.DateCreated);
                    if (isDefined($scope.job.DateCompleted)) {
                        $scope.job.DateCompleted = CSharpDateToString($scope.job.DateCompleted);
                    }
                    $scope.job.CalculatingWaitingRatio = ($scope.job.TotalCalculatingTime / $scope.job.TotalWaitingTime);
                    $scope.job.AvgTransferringTime = $scope.job.AvgTransferringTime.toHHMMSS();
                    $scope.job.AvgCalculatingTime = $scope.job.AvgCalculatingTime.toHHMMSS();
                    $scope.job.MinCalculatingTime = $scope.job.MinCalculatingTime.toHHMMSS();
                    $scope.job.MaxCalculatingTime = $scope.job.MaxCalculatingTime.toHHMMSS();
                    $scope.job.TotalCalculatingTime = $scope.job.TotalCalculatingTime.toHHMMSS();
                    $scope.job.TotalWaitingTime = $scope.job.TotalWaitingTime.toHHMMSS();
                    $scope.job.TotalTime = $scope.job.TotalTime.toHHMMSS();

                    var length = job.TasksStates.length;
                    var total = 0;
                    var jsStates = [];
                    for (var i = 0; i < length; ++i) {
                        var state = job.TasksStates[i];
                        var selected = true;
                        if (isDefined($scope.states)) {
                            for (var j = 0; j < $scope.states.length; ++j) {
                                if (state.State == $scope.states[j].State) {
                                    selected = $scope.states[j].Selected;
                                    break;
                                }
                            }
                        }
                        jsStates.push({
                            State: state.State,
                            Count: state.Count,
                            Selected: selected
                        });
                        total += state.Count;
                    }
                    $scope.totalJobTasks = total;
                    $scope.states = jsStates;
                    getTasks();
                });
            };

            var getTasks = function () {
                var states = [];
                var length = $scope.states.length;
                for (var i = 0; i < length; ++i) {
                    var state = $scope.states[i];
                    if (state.Selected) {
                        states.push(state.State);
                    }
                }

                taskService.getTasksByJobId({ id: $stateParams.id, page: $scope.curTaskPage, size: $scope.taskPageSize }, states,
                    function (taskPage) {
                        $scope.taskPage = taskPage;
                        var length = $scope.taskPage.Tasks.length;
                        for (var i = 0; i < length; ++i) {
                            $scope.taskPage.Tasks[i].TotalTime = $scope.taskPage.Tasks[i].TotalTime.toHHMMSS();
                            $scope.taskPage.Tasks[i].InitialWaitingTime = $scope.taskPage.Tasks[i].InitialWaitingTime.toHHMMSS();
                            $scope.taskPage.Tasks[i].WaitingTime = $scope.taskPage.Tasks[i].WaitingTime.toHHMMSS();
                            $scope.taskPage.Tasks[i].CalculatingTime = $scope.taskPage.Tasks[i].CalculatingTime.toHHMMSS();
                            $scope.taskPage.Tasks[i].TransferTime = $scope.taskPage.Tasks[i].TransferTime.toHHMMSS();
                            var startTime = $scope.taskPage.Tasks[i].StartTime;
                            if (isDefined(startTime)) {
                                $scope.taskPage.Tasks[i].StartTime = CSharpDateToString(startTime);
                            } else {
                                $scope.taskPage.Tasks[i].StartTime = 'Not started';
                            }
                            var endTime = $scope.taskPage.Tasks[i].EndTime;
                            if (isDefined(endTime)) {
                                $scope.taskPage.Tasks[i].EndTime = CSharpDateToString(endTime);
                            } else {
                                $scope.taskPage.Tasks[i].EndTime = 'Not finished';
                            }
                        }
                    }
                );
            };

            $scope.changeTaskPage = function () {
                getJobDetails();
                $('html, body').animate({
                    scrollTop: $("#job-filter-header").offset().top
                }, 10);
            };

            $scope.filterState = function (state) {
                state.Selected = !state.Selected;
                $scope.curTaskPage = 1;
                getJobDetails();
            };

            $scope.openDialog = function (taskNo, task) {
                $scope.currentTaskNo = taskNo;
                $scope.currentTask = task;
                $modal.open({
                    templateUrl: 'plugin=statistics&view=WebApp/jobs/details/jobTaskDetailsDialog.cshtml',
                    controller: 'app.statistics.jobTaskDetailsDialogCtrl',
                    windowClass: 'app-modal-window',
                    resolve: {
                        task: function() {
                            return $scope.currentTask;
                        },
                        taskNo: function() {
                            return $scope.currentTaskNo;
                        }
                    }
                });
            };

            var update = function () {
                getJobDetails();
            };

            $scope.updateInterval = $interval(update, $scope.interval);
            var cancelInterval = $scope.$on('$locationChangeSuccess', function () {
                $interval.cancel($scope.updateInterval);
                cancelInterval();
            });
            update(); // init page
        }]
    );
})();